==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/TelephonyResponseCommandsInner.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.TelephonyResponseCommandsInnerValueInner;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * TelephonyResponseCommandsInner
 */
@JsonPropertyOrder({ TelephonyResponseCommandsInner.JSON_PROPERTY_TYPE,
        TelephonyResponseCommandsInner.JSON_PROPERTY_VALUE })
@JsonTypeName("TelephonyResponse_commands_inner")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class TelephonyResponseCommandsInner implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_TYPE = "type";
    private String type;

    public static final String JSON_PROPERTY_VALUE = "value";
    private List<TelephonyResponseCommandsInnerValueInner> value = null;

    public TelephonyResponseCommandsInner() {
    }

    public TelephonyResponseCommandsInner type(String type) {

        this.type = type;
        return this;
    }

    /**
     * The location where you specify the command. For the Telephony inline hook, there&#39;s only one command,
     * &#x60;com.okta.telephony.action&#x60;.
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The location where you specify the command. For the Telephony inline hook, there's only one command, `com.okta.telephony.action`.")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(String type) {
        this.type = type;
    }

    public TelephonyResponseCommandsInner value(List<TelephonyResponseCommandsInnerValueInner> value) {

        this.value = value;
        return this;
    }

    public TelephonyResponseCommandsInner addvalueItem(TelephonyResponseCommandsInnerValueInner valueItem) {
        if (this.value == null) {
            this.value = new ArrayList<>();
        }
        this.value.add(valueItem);
        return this;
    }

    /**
     * The status of the telephony operation along with optional additional information about the provider, transaction
     * ID and any other transaction metadata.
     *
     * @return value
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The status of the telephony operation along with optional additional information about the provider, transaction ID and any other transaction metadata.")
    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<TelephonyResponseCommandsInnerValueInner> getValue() {
        return value;
    }

    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setValue(List<TelephonyResponseCommandsInnerValueInner> value) {
        this.value = value;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        TelephonyResponseCommandsInner telephonyResponseCommandsInner = (TelephonyResponseCommandsInner) o;
        return Objects.equals(this.type, telephonyResponseCommandsInner.type)
                && Objects.equals(this.value, telephonyResponseCommandsInner.value);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(type, value);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class TelephonyResponseCommandsInner {\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("    value: ").append(toIndentedString(value)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/TelephonyResponseCommandsInner.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.TelephonyResponseCommandsInnerValueInner;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * TelephonyResponseCommandsInner
 */
@JsonPropertyOrder({ TelephonyResponseCommandsInner.JSON_PROPERTY_TYPE,
        TelephonyResponseCommandsInner.JSON_PROPERTY_VALUE })
@JsonTypeName("TelephonyResponse_commands_inner")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class TelephonyResponseCommandsInner implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_TYPE = "type";
    private String type;

    public static final String JSON_PROPERTY_VALUE = "value";
    private List<TelephonyResponseCommandsInnerValueInner> value = null;

    public TelephonyResponseCommandsInner() {
    }

    public TelephonyResponseCommandsInner type(String type) {

        this.type = type;
        return this;
    }

    /**
     * The location where you specify the command. For the Telephony inline hook, there&#39;s only one command,
     * &#x60;com.okta.telephony.action&#x60;.
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The location where you specify the command. For the Telephony inline hook, there's only one command, `com.okta.telephony.action`.")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(String type) {
        this.type = type;
    }

    public TelephonyResponseCommandsInner value(List<TelephonyResponseCommandsInnerValueInner> value) {

        this.value = value;
        return this;
    }

    public TelephonyResponseCommandsInner addvalueItem(TelephonyResponseCommandsInnerValueInner valueItem) {
        if (this.value == null) {
            this.value = new ArrayList<>();
        }
        this.value.add(valueItem);
        return this;
    }

    /**
     * The status of the telephony operation along with optional additional information about the provider, transaction
     * ID and any other transaction metadata.
     *
     * @return value
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The status of the telephony operation along with optional additional information about the provider, transaction ID and any other transaction metadata.")
    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<TelephonyResponseCommandsInnerValueInner> getValue() {
        return value;
    }

    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setValue(List<TelephonyResponseCommandsInnerValueInner> value) {
        this.value = value;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        TelephonyResponseCommandsInner telephonyResponseCommandsInner = (TelephonyResponseCommandsInner) o;
        return Objects.equals(this.type, telephonyResponseCommandsInner.type)
                && Objects.equals(this.value, telephonyResponseCommandsInner.value);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(type, value);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class TelephonyResponseCommandsInner {\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("    value: ").append(toIndentedString(value)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
